#!/usr/bin/perl

use strict;
use FDN::Web::Array;
use FDN::Web::Forms;
use FDN::Common::Logger;
use FDN::Common::Utils;
use FDN::Adsl::Adhs;
use FDN::Adsl::Basic;
use FDN::Adsl::Infos;
use FDN::Adsl::Utils;

prepare_page_adh();

my $page = '';
my $cid = $sess->{content}->{cid};

my $cfg = 'adsl/adhs/adh.cfg';
my $form = form_read( $cfg, 'subdon' );

if (!defined $form) {
	$page .= "<p>Echec chargement formulaire</p>";
	eject_page_adh($page);
	exit(0);
}

my $montant_s = $vars->{montant};
$montant_s =~ s/,/./;
my $montant = $montant_s * 100;

if ( $vars->{do} eq 'yes' ) {
	if ( ! check_transition($form, $vars) ) {
		info('Formulaire invalide');
		$page .= affiche_form($form, $vars);
	} elsif ($vars->{typedon} eq 'ponctuel' &&
		defined $vars->{fin} && $vars->{fin} ne '') {
		info('Formulaire invalide');
		add_form_error('syntax', 'Il ne faut pas de date de fin pour un don ponctuel.');
		$page .= affiche_form($form, $vars);
	} elsif ($montant < 500) {
		info('Formulaire invalide');
		add_form_error('syntax', 'Le montant doit tre au moins de 5 euros.');
		$page .= affiche_form($form, $vars);
	} else {
		my $id = new_don($cid, 'ok', $vars->{typedon}, "Don ".$vars->{destinationdon}, $montant);
		my $debut = $vars->{debut};
		if (defined $debut && $debut ne '') {
			$debut .= " 00:00:00";
		} else {
			$debut = get_timestamp();
		}
		if ($vars->{typedon} eq "ponctuel") {
			set_don_date($id, $debut);
		} else {
			set_don_debut($id, $debut);
			if (defined $vars->{fin} && $vars->{fin} ne '') {
				set_don_fin($id, $vars->{fin}." 00:00:00");
			} else {
				set_don_fin($id, "9999-12-31 23:59:59");
			}
		}
		info('Don ajout');
	}
} else {
	$page .= affiche_form($form, $vars);
}

# Lister les dons de l'adherent, y compris le nouveau
my @list = don_par_client_id($cid);

$page .= tableau_2d('adsl/adhs/rewrite.tbl','don',\@list,'Liste des dons souscrits');

eject_page_adh($page);
