#!/usr/bin/perl

use strict;
use List::Util qw (first);
use FDN::Common::Config;
use FDN::Web::Array;
use FDN::Adsl::Adhs;
use FDN::Adsl::Ag;
use FDN::Adsl::Basic;

prepare_page_adh(only_for_adh => 1);

my $cid = $sess->{content}->{cid};
my $page = '<table style="max-width: 600px">'."\n<tr><td><h2>Votes passs et en cours</h2></td></tr></table>\n\n";
my $conv = ensure_vote($cid);
if ( ! $conv ) {
	$page .= '<div class="error">Erreur interne, contacter le bureau</div>'."\n</div>";
	eject_page_adh($page);
	exit(0);
}

$page .= "<table style=\"max-width: 600px\"><tr><td>";
$page .= "<p>Cliquez sur le lien <strong>Modifier</strong> du vote pour choisir ce que vous votez.</p>\n";
$page .= '</td></tr></table>';

$page .= "<table style=\"max-width: 600px\">\n";
my $votes = Config_Key('adsl/adhs/vote.cfg', 'vote', '@votes');
my $gcfg = Load_Config('adsl/adhs/vote.cfg');
for my $vote ( @$votes ) {
	my $cfg = $gcfg->{"vote-$vote"};
	my $levote = get_vote($cid, $vote);
	my $client = client_par_id($cid);
	my $numadh = $client->{CLIENT_NUMADH};
	my $droit;

	next if (defined $cfg->{'@seulement'} and 
		 not defined first { $_ eq $numadh }
		 	@{$cfg->{'@seulement'}});

	my $texte = $cfg->{'texte'};
	$page .= "<tr><td width=\"600px\"><h5>$texte</h5></td></tr>\n";

	my $date = $cfg->{'date'};
	if (!defined $date or $date eq '') {
		$droit = "N/A";
		$date = "N/A";
		$levote = "N/A";
	} else {
		$droit = droit_de_vote($cid, $date, 'vote');
		if ($droit) {
			if (defined $levote and $levote ne '') {
				my @lesvotes = split /;/,$levote;

				# On affiche les choix faits cte  cte
				$levote = '';
				my $votenum = 0;
				my $premier = 1;

				for my $fldname ( @{$cfg->{'@fields'}} ) {
					my $choix = $lesvotes[$votenum];
					if ($premier) {
						$premier = 0;
					} else {
						$levote .= ' et ';
					}

					my $sv = $gcfg->{"selval-$choix"};
					if (defined $sv) {
						$levote .= $sv->{label};
					} else {
						$levote .= "Bulletin '$choix' invalide !";
					}
					$votenum += 1;
				}
			}
			if (!defined $levote or $levote eq '') {
				$levote = "n'a pas vot";
			}
			$droit = "oui";
		} else {
			$levote = "N/A";
			$droit = "non";
		}
	}

	# On montre les questions et les rponses possibles
	for my $fldname ( @{$cfg->{'@fields'}} ) {
		my $field = $gcfg->{'field-'.$fldname};
		my $label = $field->{label};

		$page .= "<tr><td>$label ";
		my $first = 1;
		for my $choix (@{$field->{'@values'}}) {
			if ($first) {
				$first = 0;
			} else {
				$page .= " ou bien ";
			}
			my $sv = $gcfg->{"selval-$choix"};
			$page .= "<b>$sv->{label}</b>";
		}
		$page .= "</tr></td>";
	}

	$page .= "<tr><td>Date limite de vote: $date</td></tr>\n".
	         "<tr><td>Droit de vote: $droit</td></tr>\n";

	if ( $cfg->{'status'} eq 'new' ) {
	        $page .= "<tr><td>Vote: N/A</td></tr>\n<tr><td>&nbsp;</td></tr>\n";
		next;
	}

	if ($droit eq 'oui') {
		if ($cfg->{secret} ne 'false') {
			my $hash = get_vote_hash($cid, $vote);
			$page .= "<tr><td>Bulletin secret: $hash</td></tr>\n";
		} else {
			$page .= "<tr><td>Bulletin public</td></tr>\n";
		}
		$page .= "<tr><td>&nbsp;</td></tr>\n";
		$page .= "<tr><td>Vote: $levote</td></tr>\n";
	}

	if ( $cfg->{'status'} eq 'open') {
		if ($droit eq 'oui') {
			$page .= '<tr><td><a href="adh-voteedit.cgi?sess=%%sess%%&vote='.$vote.'">Modifier</a></td></tr>'."<tr><td>&nbsp;</td></tr>\n";
		}
		next;
	}

	if ( $cfg->{'status'} eq 'close' ) {
		$page .= "<tr><td>&nbsp;</td></tr>\n";
		next;
	}
	if ( $cfg->{'status'} eq 'old' ) {
		$page .= '<tr><td><a href="adh-votelist.cgi?sess=%%sess%%&vote='.$vote.'">Rsultats</a></td></tr>'."<tr><td>&nbsp;</td></tr>\n";
		next;
	}
	$page .= '<tr><td><div class="error">Les informations connues pour le vote '.$vote.' sont invalides. Je ne sais pas afficher a. Contacter le bureau.</div></td></tr>'."<tr><td>&nbsp;</td></tr>\n";
}

$page .= "</table>\n";

$page .= "<table style=\"max-width: 600px\"><tr><td>";
$page .= "<h4>Lgende</h4>\n".
	"<p><strong>Droit de vote</strong> indique si vous avez, ou pas, le droit de vote pour ce vote (le droit de vote est acquis aprs un an rvolu d'adhsion  l'association).</p>\n";

$page .= '</td></tr></table>';

eject_page_adh($page);


