#!/usr/bin/perl

use strict;
use FDN::Web::Array;
use FDN::Adsl::Utils;
use FDN::Adsl::Basic;
use FDN::Adsl::Adhs;
use IPC::Open2;

prepare_page_adh();

# Comment rcuprer le 95e percentile de la priode entre $start et $end
sub get_95e($$) {
	my ($start, $end) = @_;
	return "rrdtool graph -s $start -e $end - ".
		"DEF:in=\$i:traffic_in:AVERAGE ".
		"DEF:out=\$i:traffic_out:AVERAGE ".
		"CDEF:max=in,out,MAX ".
		"'CDEF:maxbits=max,8,*' ".
		"VDEF:pct=maxbits,95,PERCENT ".
		"'PRINT:pct: %8lf'";
}

my $res;
my $fh;

# Rcuprer les diffrents percentiles
$res = open $fh, '( cd /var/lib/rrd ; for i in *.rrd ; do echo -n "$i " ; '.
'val=$('.get_95e('-1mon', 'now').' | tail -n 1) ; echo -n "$val " ; '.
'echo ; done ) |';

if ( ! $res ) {
	eject_page_error("couldn't start rrdtool");
}

my $login;
my $min;
my $jour;
my $semaine;
my $mois;

my $stats_mois_vpn;
my $stats_mois_adsl;
my $stats_mois_vdsl;
my $stats_mois_ftth;

while (<$fh>)
{
	($login,$mois) = split ' ';
	if ($mois eq '-nan') { $mois = 0; }
	$login =~ s/.rrd$//;
	if ($login =~ /^.*\@fdn.ilf.kosc$/) {
		push @$stats_mois_ftth, $mois;
	} elsif ($login =~ /^.*\@fdn.ilf.bouygues$/) {
		push @$stats_mois_ftth, $mois;
	} elsif ($login =~ /^.*\@vpn.fdn.fr$/) {
		push @$stats_mois_vpn, $mois;
	} else {
		my $ru = raduser_par_login($login);
		my $lid = $ru->{LIGNE_ID};
		if ($lid >= 0) {
			my $ligne = ligne_par_id($lid);
			if ($ligne->{DEBIT_ID} == 16) {
				# VDSL
				push @$stats_mois_vdsl, $mois;
			}
			else
			{
				push @$stats_mois_adsl, $mois;
			}
		}
	}
}

my ($fhr, $fhw);

my $pid = open2($fhr, $fhw, "gnuplot");

print { $fhw } "set terminal png\n";
print { $fhw } "set logscale x\n";
print { $fhw } "set xtics out scale 3\n";
print { $fhw } "set xlabel 'Debit (Mbps)'\n";
print { $fhw } "set ylabel 'Nombre d usagers a ce debit'\n";
print { $fhw } "set yrange [0:25]\n";
#print { $fhw } "set style data histogram\n";
#print { $fhw } "set style fill solid border -1\n";
#print { $fhw } "set style histogram cluster gap 0\n";
#print { $fhw } "set xtics rotate\n";
#print { $fhw } "plot '-' using 2:xtic(1) notitle\n";
print { $fhw } "plot '-' using 1:2 title 'vpn' with linespoint, '' using 1:2 title 'adsl' with linespoint, '' using 1:2 title 'vdsl' with linespoint, '' using 1:2 title 'ftth' with linespoint\n";

sub mydump($) {
	my ($data) = @_;
	my $prevpalier = 0;
	my $palier = 0.1;
	my $continue = 1;
	while ($continue) {
		my $n = 0;
		$continue = 0;
		for my $mois (@$data) {
			if ($mois > $palier * 1000000) {
				$continue = 1;
			}
			if ($mois > $prevpalier * 1000000 && $mois <= $palier * 1000000) {
				$n++;
			}
		}
		print { $fhw } "$palier $n\n";
		$prevpalier = $palier;
		$palier *= 1.2;
	}
	print { $fhw } "e\n";
}

mydump($stats_mois_vpn);
mydump($stats_mois_adsl);
mydump($stats_mois_vdsl);
mydump($stats_mois_ftth);

close($fhw);

send_png_file($fhr);
close($fhr);

## Ajouter des lments "utilisateur Radius" dans un tableau, avec les stats 
## ct.
#my @users;
#foreach $login (sort {&$letri($b,$a)} keys %stats_min) {
#	my $fdn_login = $login;
#	$fdn_login =~ s/^.*%//;
#	my $ru = raduser_par_login($fdn_login);
#	if (!$ru) {
#		# Build a fake ru
#		$ru->{'RADUSER_ID'} = -1;
#		$ru->{'RADUSER_LOGIN'} = $login;
#		$ru->{'RADGROUP_ID'} = -1;
#		$ru->{'LIGNE_ID'} = -1;
#		$ru->{'VPN_ID'} = -1;
#	}
#	$ru->{'MOIS'} = int($stats_mois{$login}/100000)/10;
#	push @users, $ru;
#}
#
#eject_page(tableau_2d('adsl/rewrite.tbl','raduser-detail',\@users,"Liste des connects par dbit, tri par $dotrimin, $dotrijour, $dotrisemaine, $dotrimois"));
