#!/usr/bin/perl

use strict;
use CGI;
use FDN::Common::Logger;
use FDN::Web::Forms;
use FDN::Web::Session;
use FDN::Adsl::Basic;
use FDN::Adsl::Utils;
use FDN::Adsl::Adhs;

my $form = form_read('adsl/adhs/adh.cfg','in');
my $cgi = new CGI;
my $vars = $cgi->Vars;

if ( $vars->{'do'} ne 'yes' ) {
	eject_page_adh(affiche_form($form,$vars));
	exit(0);
}

if ( ! check_transition($form,$vars) ) {
	eject_page_adh(affiche_form($form,$vars));
	exit(0);
}

my $use_rad;
my $use_tel;
my $use_vpn;
my $use_adh;

my $login = $vars->{'login'};
my $passwd = $vars->{'passwd'};

my $err = "<div class=\"error\"><p>Erreur d'authentification</p></div>";
my $page;

my $logok;
my $cid;

{
	my $ligne = ligne_par_tel($login);
	if ( ! defined $ligne ) {
		#info "Numero de telephone inconnu";
		next;
	}
	my @dpls = deploiement_par_ligne_id($ligne->{'LIGNE_ID'});
	my $ok = 0;
	for my $dpl ( @dpls ) {
		if ( $dpl->{'DEPLOIEMENT_NUM'} eq $passwd ) {
			$ok = 1;
		}
	}
	if ( ! $ok ) {
		info "Numero de commande incorrect";
		next;
	}
	$cid = $ligne->{'CLIENT_ID'};
	my $client = client_par_id($cid);
	if ( $client->{'CLIENT_ETAT'} eq 'resilie' ) {
		info "Adherent resilie";
		next;
	}
	if ( $client->{'CLIENT_TYPE'} =~ /^(blanche|collecte)$/ ) {
		next;
	}
	$logok = 1;
	goto GOOD;
}
{
	my $vid = $login;
	$vid =~ s/^vpn//;
	my $vpn = vpn_par_id($vid);
	if ( ! defined $vpn ) {
		#info "Numero de vpn inconnu";
		next;
	}
	my $dpl = deploiement_par_vpn_id($vid);
	if ( ! defined $dpl ) {
		info "Numero de commande inconnu";
		next;
	}
	if ( $dpl->{'DEPLOIEMENT_NUM'} ne $passwd ) {
		info "Numero de VPN et de commande ne correspondent pas";
		next;
	}
	$cid = $vpn->{'CLIENT_ID'};
	my $client = client_par_id($cid);
	if ( $client->{'CLIENT_ETAT'} eq 'resilie' ) {
		info "Adherent resilie";
		next;
	}
	if ( $client->{'CLIENT_TYPE'} =~ /^(blanche|collecte)$/ ) {
		next;
	}
	$logok = 1;
	goto GOOD;
}
RADUSER: {
	my $ru = raduser_par_login($login);
	if ( ! defined $ru ) {
		#info "Login radius inconnu";
		next;
	}
	my @attrs = uattr_par_raduser_id_type($ru->{'RADUSER_ID'},'check');
	for my $attr ( @attrs ) {
		next if ( ! defined $attr );
		debug "Vu attribut ".$attr->{'UATTR_ATTR'}." valeur ".$attr->{'UATTR_VALUE'};
		if ( $attr->{'UATTR_ATTR'} eq 'User-Password' &&
		     $attr->{'UATTR_VALUE'} eq $passwd ) {
			if ($ru->{'LIGNE_ID'} != -1) {
				my $ligne = ligne_par_id($ru->{'LIGNE_ID'});
				$cid = $ligne->{'CLIENT_ID'};
			}
			if ($ru->{'VPN_ID'} != -1) {
				my $vpn = vpn_par_id($ru->{'VPN_ID'});
				$cid = $vpn->{'CLIENT_ID'};
			}
			my $client = client_par_id($cid);
			if ( $client->{'CLIENT_ETAT'} eq 'resilie' ) {
				info "Adherent resilie";
				next RADUSER;
			}
			if ( $client->{'CLIENT_TYPE'} =~ /^(blanche|collecte)$/ ) {
				next RADUSER;
			}
			$logok = 1;
			goto GOOD;
		}
	}
	$logok = 0;
	info "Mot de passe radius ne correspond pas";
}
{
	my $adh = adhaccess_par_login($login);
	if ( ! defined $adh ) {
		#info "Identifiant adherent inconnu";
		next;
	}
	$cid = $adh->{'CLIENT_ID'};
	my $client = client_par_id($cid);
	if ( $client->{'CLIENT_ETAT'} eq 'resilie' ) {
		info "Adherent resilie";
		next;
	}
	if ( exists $adh->{'ADHACCESS_CRYPT'} ) {
		my $crypt = $adh->{'ADHACCESS_CRYPT'};
		if ( crypt($passwd,$crypt) ne $crypt ) {
			info "Mot de passe invalide (crypt)";
			next;
		}
	} elsif ( $adh->{'ADHACCESS_PASSWD'} ne $passwd ) {
		info "Mot de passe invalide";
		next;
	}
	$logok = 1;
	# Ici, on laisse passer les clients en marque blanche, pour qu'ils voient
	# leurs factures.
}

BAD:

if ( ! $logok ) {
	$page = affiche_form($form,$vars);
	$page .= $err;
	eject_page_adh($page);
	exit(0);
}

GOOD:

my $sess = new_session('adh');
my $info = $vars->{'info'};
$sess->{content} = {
	'cid' => $cid,
	'info' => $info,
};
debug "Info: $info";
debug "Cid: $cid";
store_session($sess);
info "Connection ok. Session: ".$sess->{name};
print "Location: adh-in.cgi?sess=".$sess->{name}."\n\n";

